"""This module contains the general information for FabricSanCloud ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class FabricSanCloudConsts():
    MODE_END_HOST = "end-host"
    MODE_SWITCH = "switch"


class FabricSanCloud(ManagedObject):
    """This is FabricSanCloud class."""

    consts = FabricSanCloudConsts()
    naming_props = set([])

    mo_meta = MoMeta("FabricSanCloud", "fabricSanCloud", "san", VersionMeta.Version111a, "InputOutput", 0x1f, [], [""], ['fabricEp'], ['fabricFcSan', 'fabricFcUplinkOperation', 'fabricSanPinGroup', 'fabricSanPinGroupOperation', 'firmwareAck', 'statsThresholdPolicy'], ["Get", "Set"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "mode": MoPropertyMeta("mode", "mode", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x4, None, None, None, ["end-host", "switch"], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "mode": "mode", 
        "rn": "rn", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.mode = None
        self.status = None

        ManagedObject.__init__(self, "FabricSanCloud", parent_mo_or_dn, **kwargs)




"""This module contains the general information for ConfigCpuInfo ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class ConfigCpuInfoConsts():
    ARCH_DUAL_CORE_OPTERON = "Dual-Core_Opteron"
    ARCH_INTEL_P4_C = "Intel_P4_C"
    ARCH_OPTERON = "Opteron"
    ARCH_PENTIUM_4 = "Pentium_4"
    ARCH_TURION_64 = "Turion_64"
    ARCH_XEON = "Xeon"
    ARCH_XEON_MP = "Xeon_MP"
    ARCH_ZEN = "Zen"
    ARCH_ANY = "any"
    SPEED_UNSPECIFIED = "unspecified"


class ConfigCpuInfo(ManagedObject):
    """This is ConfigCpuInfo class."""

    consts = ConfigCpuInfoConsts()
    naming_props = set(['arch'])

    mo_meta = MoMeta("ConfigCpuInfo", "configCpuInfo", "cpu-info-[arch]", VersionMeta.Version131a, "InputOutput", 0x1f, [], ["read-only"], ['configServerItem'], [], [None])

    prop_meta = {
        "arch": MoPropertyMeta("arch", "arch", "string", VersionMeta.Version131a, MoPropertyMeta.NAMING, 0x2, None, None, None, ["Dual-Core_Opteron", "Intel_P4_C", "Opteron", "Pentium_4", "Turion_64", "Xeon", "Xeon_MP", "Zen", "any"], []), 
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version131a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "count": MoPropertyMeta("count", "count", "ushort", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []), 
        "speed": MoPropertyMeta("speed", "speed", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["unspecified"], ["0-4294967295"]), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "arch": "arch", 
        "childAction": "child_action", 
        "count": "count", 
        "dn": "dn", 
        "rn": "rn", 
        "speed": "speed", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, arch, **kwargs):
        self._dirty_mask = 0
        self.arch = arch
        self.child_action = None
        self.count = None
        self.speed = None
        self.status = None

        ManagedObject.__init__(self, "ConfigCpuInfo", parent_mo_or_dn, **kwargs)




"""This module contains the general information for FcErrStats ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class FcErrStatsConsts():
    SUSPECT_FALSE = "false"
    SUSPECT_NO = "no"
    SUSPECT_TRUE = "true"
    SUSPECT_YES = "yes"


class FcErrStats(ManagedObject):
    """This is FcErrStats class."""

    consts = FcErrStatsConsts()
    naming_props = set([])

    mo_meta = MoMeta("FcErrStats", "fcErrStats", "err-stats", VersionMeta.Version111a, "OutputOnly", 0xf, [], ["admin", "operations", "read-only"], [], ['fcErrStatsHist'], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "crc_rx": MoPropertyMeta("crc_rx", "crcRx", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "crc_rx_delta": MoPropertyMeta("crc_rx_delta", "crcRxDelta", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "crc_rx_delta_avg": MoPropertyMeta("crc_rx_delta_avg", "crcRxDeltaAvg", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "crc_rx_delta_max": MoPropertyMeta("crc_rx_delta_max", "crcRxDeltaMax", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "crc_rx_delta_min": MoPropertyMeta("crc_rx_delta_min", "crcRxDeltaMin", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "discard_rx": MoPropertyMeta("discard_rx", "discardRx", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "discard_rx_delta": MoPropertyMeta("discard_rx_delta", "discardRxDelta", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "discard_rx_delta_avg": MoPropertyMeta("discard_rx_delta_avg", "discardRxDeltaAvg", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "discard_rx_delta_max": MoPropertyMeta("discard_rx_delta_max", "discardRxDeltaMax", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "discard_rx_delta_min": MoPropertyMeta("discard_rx_delta_min", "discardRxDeltaMin", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "discard_tx": MoPropertyMeta("discard_tx", "discardTx", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "discard_tx_delta": MoPropertyMeta("discard_tx_delta", "discardTxDelta", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "discard_tx_delta_avg": MoPropertyMeta("discard_tx_delta_avg", "discardTxDeltaAvg", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "discard_tx_delta_max": MoPropertyMeta("discard_tx_delta_max", "discardTxDeltaMax", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "discard_tx_delta_min": MoPropertyMeta("discard_tx_delta_min", "discardTxDeltaMin", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "intervals": MoPropertyMeta("intervals", "intervals", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "link_failures": MoPropertyMeta("link_failures", "linkFailures", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "link_failures_delta": MoPropertyMeta("link_failures_delta", "linkFailuresDelta", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "link_failures_delta_avg": MoPropertyMeta("link_failures_delta_avg", "linkFailuresDeltaAvg", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "link_failures_delta_max": MoPropertyMeta("link_failures_delta_max", "linkFailuresDeltaMax", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "link_failures_delta_min": MoPropertyMeta("link_failures_delta_min", "linkFailuresDeltaMin", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "normalized_time_col": MoPropertyMeta("normalized_time_col", "normalizedTimeCol", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "rx": MoPropertyMeta("rx", "rx", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "rx_delta": MoPropertyMeta("rx_delta", "rxDelta", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "rx_delta_avg": MoPropertyMeta("rx_delta_avg", "rxDeltaAvg", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "rx_delta_max": MoPropertyMeta("rx_delta_max", "rxDeltaMax", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "rx_delta_min": MoPropertyMeta("rx_delta_min", "rxDeltaMin", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "signal_losses": MoPropertyMeta("signal_losses", "signalLosses", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "signal_losses_delta": MoPropertyMeta("signal_losses_delta", "signalLossesDelta", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "signal_losses_delta_avg": MoPropertyMeta("signal_losses_delta_avg", "signalLossesDeltaAvg", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "signal_losses_delta_max": MoPropertyMeta("signal_losses_delta_max", "signalLossesDeltaMax", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "signal_losses_delta_min": MoPropertyMeta("signal_losses_delta_min", "signalLossesDeltaMin", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "stats_reported": MoPropertyMeta("stats_reported", "statsReported", "int", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "suspect": MoPropertyMeta("suspect", "suspect", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []), 
        "sync_losses": MoPropertyMeta("sync_losses", "syncLosses", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "sync_losses_delta": MoPropertyMeta("sync_losses_delta", "syncLossesDelta", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "sync_losses_delta_avg": MoPropertyMeta("sync_losses_delta_avg", "syncLossesDeltaAvg", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "sync_losses_delta_max": MoPropertyMeta("sync_losses_delta_max", "syncLossesDeltaMax", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "sync_losses_delta_min": MoPropertyMeta("sync_losses_delta_min", "syncLossesDeltaMin", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "thresholded": MoPropertyMeta("thresholded", "thresholded", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "time_collected": MoPropertyMeta("time_collected", "timeCollected", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []), 
        "too_long_rx": MoPropertyMeta("too_long_rx", "tooLongRx", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "too_long_rx_delta": MoPropertyMeta("too_long_rx_delta", "tooLongRxDelta", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "too_long_rx_delta_avg": MoPropertyMeta("too_long_rx_delta_avg", "tooLongRxDeltaAvg", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "too_long_rx_delta_max": MoPropertyMeta("too_long_rx_delta_max", "tooLongRxDeltaMax", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "too_long_rx_delta_min": MoPropertyMeta("too_long_rx_delta_min", "tooLongRxDeltaMin", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "too_short_rx": MoPropertyMeta("too_short_rx", "tooShortRx", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "too_short_rx_delta": MoPropertyMeta("too_short_rx_delta", "tooShortRxDelta", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "too_short_rx_delta_avg": MoPropertyMeta("too_short_rx_delta_avg", "tooShortRxDeltaAvg", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "too_short_rx_delta_max": MoPropertyMeta("too_short_rx_delta_max", "tooShortRxDeltaMax", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "too_short_rx_delta_min": MoPropertyMeta("too_short_rx_delta_min", "tooShortRxDeltaMin", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "tx": MoPropertyMeta("tx", "tx", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "tx_delta": MoPropertyMeta("tx_delta", "txDelta", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "tx_delta_avg": MoPropertyMeta("tx_delta_avg", "txDeltaAvg", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "tx_delta_max": MoPropertyMeta("tx_delta_max", "txDeltaMax", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "tx_delta_min": MoPropertyMeta("tx_delta_min", "txDeltaMin", "ulong", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "update": MoPropertyMeta("update", "update", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "crcRx": "crc_rx", 
        "crcRxDelta": "crc_rx_delta", 
        "crcRxDeltaAvg": "crc_rx_delta_avg", 
        "crcRxDeltaMax": "crc_rx_delta_max", 
        "crcRxDeltaMin": "crc_rx_delta_min", 
        "discardRx": "discard_rx", 
        "discardRxDelta": "discard_rx_delta", 
        "discardRxDeltaAvg": "discard_rx_delta_avg", 
        "discardRxDeltaMax": "discard_rx_delta_max", 
        "discardRxDeltaMin": "discard_rx_delta_min", 
        "discardTx": "discard_tx", 
        "discardTxDelta": "discard_tx_delta", 
        "discardTxDeltaAvg": "discard_tx_delta_avg", 
        "discardTxDeltaMax": "discard_tx_delta_max", 
        "discardTxDeltaMin": "discard_tx_delta_min", 
        "dn": "dn", 
        "intervals": "intervals", 
        "linkFailures": "link_failures", 
        "linkFailuresDelta": "link_failures_delta", 
        "linkFailuresDeltaAvg": "link_failures_delta_avg", 
        "linkFailuresDeltaMax": "link_failures_delta_max", 
        "linkFailuresDeltaMin": "link_failures_delta_min", 
        "normalizedTimeCol": "normalized_time_col", 
        "rn": "rn", 
        "rx": "rx", 
        "rxDelta": "rx_delta", 
        "rxDeltaAvg": "rx_delta_avg", 
        "rxDeltaMax": "rx_delta_max", 
        "rxDeltaMin": "rx_delta_min", 
        "signalLosses": "signal_losses", 
        "signalLossesDelta": "signal_losses_delta", 
        "signalLossesDeltaAvg": "signal_losses_delta_avg", 
        "signalLossesDeltaMax": "signal_losses_delta_max", 
        "signalLossesDeltaMin": "signal_losses_delta_min", 
        "statsReported": "stats_reported", 
        "status": "status", 
        "suspect": "suspect", 
        "syncLosses": "sync_losses", 
        "syncLossesDelta": "sync_losses_delta", 
        "syncLossesDeltaAvg": "sync_losses_delta_avg", 
        "syncLossesDeltaMax": "sync_losses_delta_max", 
        "syncLossesDeltaMin": "sync_losses_delta_min", 
        "thresholded": "thresholded", 
        "timeCollected": "time_collected", 
        "tooLongRx": "too_long_rx", 
        "tooLongRxDelta": "too_long_rx_delta", 
        "tooLongRxDeltaAvg": "too_long_rx_delta_avg", 
        "tooLongRxDeltaMax": "too_long_rx_delta_max", 
        "tooLongRxDeltaMin": "too_long_rx_delta_min", 
        "tooShortRx": "too_short_rx", 
        "tooShortRxDelta": "too_short_rx_delta", 
        "tooShortRxDeltaAvg": "too_short_rx_delta_avg", 
        "tooShortRxDeltaMax": "too_short_rx_delta_max", 
        "tooShortRxDeltaMin": "too_short_rx_delta_min", 
        "tx": "tx", 
        "txDelta": "tx_delta", 
        "txDeltaAvg": "tx_delta_avg", 
        "txDeltaMax": "tx_delta_max", 
        "txDeltaMin": "tx_delta_min", 
        "update": "update", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.crc_rx = None
        self.crc_rx_delta = None
        self.crc_rx_delta_avg = None
        self.crc_rx_delta_max = None
        self.crc_rx_delta_min = None
        self.discard_rx = None
        self.discard_rx_delta = None
        self.discard_rx_delta_avg = None
        self.discard_rx_delta_max = None
        self.discard_rx_delta_min = None
        self.discard_tx = None
        self.discard_tx_delta = None
        self.discard_tx_delta_avg = None
        self.discard_tx_delta_max = None
        self.discard_tx_delta_min = None
        self.intervals = None
        self.link_failures = None
        self.link_failures_delta = None
        self.link_failures_delta_avg = None
        self.link_failures_delta_max = None
        self.link_failures_delta_min = None
        self.normalized_time_col = None
        self.rx = None
        self.rx_delta = None
        self.rx_delta_avg = None
        self.rx_delta_max = None
        self.rx_delta_min = None
        self.signal_losses = None
        self.signal_losses_delta = None
        self.signal_losses_delta_avg = None
        self.signal_losses_delta_max = None
        self.signal_losses_delta_min = None
        self.stats_reported = None
        self.status = None
        self.suspect = None
        self.sync_losses = None
        self.sync_losses_delta = None
        self.sync_losses_delta_avg = None
        self.sync_losses_delta_max = None
        self.sync_losses_delta_min = None
        self.thresholded = None
        self.time_collected = None
        self.too_long_rx = None
        self.too_long_rx_delta = None
        self.too_long_rx_delta_avg = None
        self.too_long_rx_delta_max = None
        self.too_long_rx_delta_min = None
        self.too_short_rx = None
        self.too_short_rx_delta = None
        self.too_short_rx_delta_avg = None
        self.too_short_rx_delta_max = None
        self.too_short_rx_delta_min = None
        self.tx = None
        self.tx_delta = None
        self.tx_delta_avg = None
        self.tx_delta_max = None
        self.tx_delta_min = None
        self.update = None

        ManagedObject.__init__(self, "FcErrStats", parent_mo_or_dn, **kwargs)




"""This module contains the general information for FabricChangedObjectRef ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class FabricChangedObjectRefConsts():
    CENTRAL_RANGE_CHECK_CONFIG_STATE_DEPLOYMENT_ERROR = "deployment-error"
    CENTRAL_RANGE_CHECK_CONFIG_STATE_NOT_DEPLOYED_YET = "not-deployed-yet"
    REF_OBJ_STATUS_CREATED = "created"
    REF_OBJ_STATUS_DELETED = "deleted"
    REF_OBJ_STATUS_INTENT_DELETION = "intent-deletion"
    REF_OBJ_STATUS_MODIFIED = "modified"
    UCSM_DEPLOYMENT_CONFIG_STATE_DEPLOYMENT_ERROR = "deployment-error"
    UCSM_DEPLOYMENT_CONFIG_STATE_NOT_DEPLOYED_YET = "not-deployed-yet"


class FabricChangedObjectRef(ManagedObject):
    """This is FabricChangedObjectRef class."""

    consts = FabricChangedObjectRefConsts()
    naming_props = set(['id'])

    mo_meta = MoMeta("FabricChangedObjectRef", "fabricChangedObjectRef", "ChangedObjectRef[id]", VersionMeta.Version111a, "InputOutput", 0x1f, [], ["read-only"], ['fabricVnetEpSyncEp'], ['faultInst'], [None])

    prop_meta = {
        "central_range_check_config_state": MoPropertyMeta("central_range_check_config_state", "centralRangeCheckConfigState", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["deployment-error", "not-deployed-yet"], []), 
        "centrale_vnet_ep_dn": MoPropertyMeta("centrale_vnet_ep_dn", "centraleVnetEpDn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "config_range_message": MoPropertyMeta("config_range_message", "configRangeMessage", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "id": MoPropertyMeta("id", "id", "uint", VersionMeta.Version111a, MoPropertyMeta.NAMING, 0x4, None, None, None, [], []), 
        "old_centrale_vnet_ep_dn": MoPropertyMeta("old_centrale_vnet_ep_dn", "oldCentraleVnetEpDn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "ref_obj_status": MoPropertyMeta("ref_obj_status", "refObjStatus", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["created", "deleted", "intent-deletion", "modified"], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "ucsm_config_message": MoPropertyMeta("ucsm_config_message", "ucsmConfigMessage", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "ucsm_deployment_config_state": MoPropertyMeta("ucsm_deployment_config_state", "ucsmDeploymentConfigState", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["deployment-error", "not-deployed-yet"], []), 
        "ucsm_vnet_ep_dn": MoPropertyMeta("ucsm_vnet_ep_dn", "ucsmVnetEpDn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
    }

    prop_map = {
        "centralRangeCheckConfigState": "central_range_check_config_state", 
        "centraleVnetEpDn": "centrale_vnet_ep_dn", 
        "childAction": "child_action", 
        "configRangeMessage": "config_range_message", 
        "dn": "dn", 
        "id": "id", 
        "oldCentraleVnetEpDn": "old_centrale_vnet_ep_dn", 
        "refObjStatus": "ref_obj_status", 
        "rn": "rn", 
        "status": "status", 
        "ucsmConfigMessage": "ucsm_config_message", 
        "ucsmDeploymentConfigState": "ucsm_deployment_config_state", 
        "ucsmVnetEpDn": "ucsm_vnet_ep_dn", 
    }

    def __init__(self, parent_mo_or_dn, id, **kwargs):
        self._dirty_mask = 0
        self.id = id
        self.central_range_check_config_state = None
        self.centrale_vnet_ep_dn = None
        self.child_action = None
        self.config_range_message = None
        self.old_centrale_vnet_ep_dn = None
        self.ref_obj_status = None
        self.status = None
        self.ucsm_config_message = None
        self.ucsm_deployment_config_state = None
        self.ucsm_vnet_ep_dn = None

        ManagedObject.__init__(self, "FabricChangedObjectRef", parent_mo_or_dn, **kwargs)




"""This module contains the general information for VnicFcLif ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class VnicFcLifConsts():
    OWNER_CONN_POLICY = "conn_policy"
    OWNER_INITIATOR_POLICY = "initiator_policy"
    OWNER_LOGICAL = "logical"
    OWNER_PHYSICAL = "physical"
    OWNER_POLICY = "policy"
    OWNER_UNKNOWN = "unknown"
    SWITCH_ID_A = "A"
    SWITCH_ID_B = "B"
    SWITCH_ID_NONE = "NONE"
    SWITCH_ID_MGMT = "mgmt"
    TYPE_ETHER = "ether"
    TYPE_FC = "fc"
    TYPE_IPC = "ipc"
    TYPE_SCSI = "scsi"
    TYPE_UNKNOWN = "unknown"


class VnicFcLif(ManagedObject):
    """This is VnicFcLif class."""

    consts = VnicFcLifConsts()
    naming_props = set(['name'])

    mo_meta = MoMeta("VnicFcLif", "vnicFcLif", "eth-lif-[name]", VersionMeta.Version131a, "InputOutput", 0x7f, [], ["read-only"], [], [], ["Get"])

    prop_meta = {
        "addr": MoPropertyMeta("addr", "addr", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, 0, 256, r"""(([A-Fa-f0-9][A-Fa-f0-9]:){7}[A-Fa-f0-9][A-Fa-f0-9])|0""", [], []), 
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version131a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version131a, MoPropertyMeta.NAMING, 0x4, None, None, r"""[\-\.:_a-zA-Z0-9]{1,16}""", [], []), 
        "nic_dn": MoPropertyMeta("nic_dn", "nicDn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x8, 0, 256, None, [], []), 
        "owner": MoPropertyMeta("owner", "owner", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["conn_policy", "initiator_policy", "logical", "physical", "policy", "unknown"], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "switch_id": MoPropertyMeta("switch_id", "switchId", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["A", "B", "NONE", "mgmt"], []), 
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["ether", "fc", "ipc", "scsi", "unknown"], []), 
        "vnic_dn": MoPropertyMeta("vnic_dn", "vnicDn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x40, 0, 256, None, [], []), 
    }

    prop_map = {
        "addr": "addr", 
        "childAction": "child_action", 
        "dn": "dn", 
        "name": "name", 
        "nicDn": "nic_dn", 
        "owner": "owner", 
        "rn": "rn", 
        "status": "status", 
        "switchId": "switch_id", 
        "type": "type", 
        "vnicDn": "vnic_dn", 
    }

    def __init__(self, parent_mo_or_dn, name, **kwargs):
        self._dirty_mask = 0
        self.name = name
        self.addr = None
        self.child_action = None
        self.nic_dn = None
        self.owner = None
        self.status = None
        self.switch_id = None
        self.type = None
        self.vnic_dn = None

        ManagedObject.__init__(self, "VnicFcLif", parent_mo_or_dn, **kwargs)




"""This module contains the general information for EquipmentManufacturingDef ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class EquipmentManufacturingDefConsts():
    pass


class EquipmentManufacturingDef(ManagedObject):
    """This is EquipmentManufacturingDef class."""

    consts = EquipmentManufacturingDefConsts()
    naming_props = set([])

    mo_meta = MoMeta("EquipmentManufacturingDef", "equipmentManufacturingDef", "manufacturing", VersionMeta.Version101a, "InputOutput", 0xf, [], [""], ['adaptorFruCapProvider', 'diagSrvCapProvider', 'equipmentBladeCapProvider', 'equipmentChassisCapProvider', 'equipmentCrossFabricModuleCapProvider', 'equipmentFanModuleCapProvider', 'equipmentFexCapProvider', 'equipmentGemCapProvider', 'equipmentGraphicsCardCapProvider', 'equipmentHostIfCapProvider', 'equipmentIOCardCapProvider', 'equipmentLocalDiskCapProvider', 'equipmentLocalDiskControllerCapProvider', 'equipmentMemoryUnitCapProvider', 'equipmentPcieConnectorCapProvider', 'equipmentPcieNodeCapProvider', 'equipmentProcessorUnitCapProvider', 'equipmentPsuCapProvider', 'equipmentRackUnitCapProvider', 'equipmentServerUnitCapProvider', 'equipmentSwitchCapProvider', 'equipmentSwitchIOCardCapProvider', 'equipmentSystemFruCapProvider'], [], ["Get"])

    prop_meta = {
        "caption": MoPropertyMeta("caption", "caption", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "clei": MoPropertyMeta("clei", "clei", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "description": MoPropertyMeta("description", "description", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "fru_major_type": MoPropertyMeta("fru_major_type", "fruMajorType", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "fru_minor_type": MoPropertyMeta("fru_minor_type", "fruMinorType", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "oem_name": MoPropertyMeta("oem_name", "oemName", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "oem_part_number": MoPropertyMeta("oem_part_number", "oemPartNumber", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "part_number": MoPropertyMeta("part_number", "partNumber", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "pid": MoPropertyMeta("pid", "pid", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "series": MoPropertyMeta("series", "series", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "sku": MoPropertyMeta("sku", "sku", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "vendor_equipment_type": MoPropertyMeta("vendor_equipment_type", "vendorEquipmentType", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "vid": MoPropertyMeta("vid", "vid", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
    }

    prop_map = {
        "caption": "caption", 
        "childAction": "child_action", 
        "clei": "clei", 
        "description": "description", 
        "dn": "dn", 
        "fruMajorType": "fru_major_type", 
        "fruMinorType": "fru_minor_type", 
        "name": "name", 
        "oemName": "oem_name", 
        "oemPartNumber": "oem_part_number", 
        "partNumber": "part_number", 
        "pid": "pid", 
        "rn": "rn", 
        "series": "series", 
        "sku": "sku", 
        "status": "status", 
        "vendorEquipmentType": "vendor_equipment_type", 
        "vid": "vid", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.caption = None
        self.child_action = None
        self.clei = None
        self.description = None
        self.fru_major_type = None
        self.fru_minor_type = None
        self.name = None
        self.oem_name = None
        self.oem_part_number = None
        self.part_number = None
        self.pid = None
        self.series = None
        self.sku = None
        self.status = None
        self.vendor_equipment_type = None
        self.vid = None

        ManagedObject.__init__(self, "EquipmentManufacturingDef", parent_mo_or_dn, **kwargs)




"""This module contains the general information for StorageReplicationCtx ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class StorageReplicationCtxConsts():
    LUN_CFG_ACTION_DELETE = "delete"
    LUN_CFG_ACTION_OFFLINE = "offline"
    LUN_CFG_ACTION_ONLINE = "online"
    LUN_CFG_ACTION_RESTORE = "restore"
    LUN_CFG_ACTION_TRIGGERED = "triggered"
    TS_CREATED_ = ""


class StorageReplicationCtx(ManagedObject):
    """This is StorageReplicationCtx class."""

    consts = StorageReplicationCtxConsts()
    naming_props = set([])

    mo_meta = MoMeta("StorageReplicationCtx", "storageReplicationCtx", "repl-ctx", VersionMeta.Version141a, "InputOutput", 0x1f, [], ["admin", "ls-compute", "ls-config", "ls-server", "ls-storage"], ['storageScsiLun'], [], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version141a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "lun_cfg_action": MoPropertyMeta("lun_cfg_action", "lunCfgAction", "string", VersionMeta.Version141a, MoPropertyMeta.READ_WRITE, 0x4, None, None, None, ["delete", "offline", "online", "restore", "triggered"], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []), 
        "src_lun_addr": MoPropertyMeta("src_lun_addr", "srcLunAddr", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, r"""^[A-Za-z]([A-Za-z0-9-]*[A-Za-z0-9])?$|^[A-Za-z0-9]([A-Za-z0-9-]*[A-Za-z0-9])?(\.[A-Za-z0-9]([A-Za-z0-9-]*[A-Za-z0-9])?)*(\.[A-Za-z]([A-Za-z0-9-]*[A-Za-z0-9])?)$|^([1-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\.([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\.([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\.([1-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])$""", [], []), 
        "src_lun_dn": MoPropertyMeta("src_lun_dn", "srcLunDn", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "src_lun_name": MoPropertyMeta("src_lun_name", "srcLunName", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version141a, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "ts_created": MoPropertyMeta("ts_created", "tsCreated", "string", VersionMeta.Version141a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [""], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "lunCfgAction": "lun_cfg_action", 
        "rn": "rn", 
        "srcLunAddr": "src_lun_addr", 
        "srcLunDn": "src_lun_dn", 
        "srcLunName": "src_lun_name", 
        "status": "status", 
        "tsCreated": "ts_created", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.lun_cfg_action = None
        self.src_lun_addr = None
        self.src_lun_dn = None
        self.src_lun_name = None
        self.status = None
        self.ts_created = None

        ManagedObject.__init__(self, "StorageReplicationCtx", parent_mo_or_dn, **kwargs)




"""This module contains the general information for LstorageRequestCtx ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class LstorageRequestCtxConsts():
    pass


class LstorageRequestCtx(ManagedObject):
    """This is LstorageRequestCtx class."""

    consts = LstorageRequestCtxConsts()
    naming_props = set([])

    mo_meta = MoMeta("LstorageRequestCtx", "lstorageRequestCtx", "", VersionMeta.Version131a, "InputOutput", 0xf, [], ["read-only"], [], [], [None])

    prop_meta = {
        "assigned_volume": MoPropertyMeta("assigned_volume", "assignedVolume", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version131a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "cons_dn": MoPropertyMeta("cons_dn", "consDn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "request_size": MoPropertyMeta("request_size", "requestSize", "ulong", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "volume_pool_name": MoPropertyMeta("volume_pool_name", "volumePoolName", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []), 
    }

    prop_map = {
        "assignedVolume": "assigned_volume", 
        "childAction": "child_action", 
        "consDn": "cons_dn", 
        "dn": "dn", 
        "requestSize": "request_size", 
        "rn": "rn", 
        "status": "status", 
        "volumePoolName": "volume_pool_name", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.assigned_volume = None
        self.child_action = None
        self.cons_dn = None
        self.request_size = None
        self.status = None
        self.volume_pool_name = None

        ManagedObject.__init__(self, "LstorageRequestCtx", parent_mo_or_dn, **kwargs)




"""This module contains the general information for GlRequestFsmStage ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class GlRequestFsmStageConsts():
    LAST_UPDATE_TIME_ = ""
    NAME_CREATE_GLOBAL_ID_POOL_BEGIN = "CreateGlobalIdPoolBegin"
    NAME_CREATE_GLOBAL_ID_POOL_CREATE_POLICIES = "CreateGlobalIdPoolCreatePolicies"
    NAME_CREATE_GLOBAL_ID_POOL_FAIL = "CreateGlobalIdPoolFail"
    NAME_CREATE_GLOBAL_ID_POOL_SUCCESS = "CreateGlobalIdPoolSuccess"
    NAME_CREATE_GLOBAL_POLICY_BEGIN = "CreateGlobalPolicyBegin"
    NAME_CREATE_GLOBAL_POLICY_CREATE_POLICIES = "CreateGlobalPolicyCreatePolicies"
    NAME_CREATE_GLOBAL_POLICY_FAIL = "CreateGlobalPolicyFail"
    NAME_CREATE_GLOBAL_POLICY_SUCCESS = "CreateGlobalPolicySuccess"
    NAME_EVALUATE_BEGIN = "EvaluateBegin"
    NAME_EVALUATE_EVALUATE = "EvaluateEvaluate"
    NAME_EVALUATE_FAIL = "EvaluateFail"
    NAME_EVALUATE_FETCH_DOMAIN_DATA = "EvaluateFetchDomainData"
    NAME_EVALUATE_SUCCESS = "EvaluateSuccess"
    NAME_EVALUATE_VALIDATE = "EvaluateValidate"
    NAME_GLOBALIZE_ADD_ID_TO_GLOBAL_POOL = "GlobalizeAddIdToGlobalPool"
    NAME_GLOBALIZE_ASSIGN_IDS = "GlobalizeAssignIds"
    NAME_GLOBALIZE_BEGIN = "GlobalizeBegin"
    NAME_GLOBALIZE_CREATE_GSP = "GlobalizeCreateGSP"
    NAME_GLOBALIZE_CREATE_ORG = "GlobalizeCreateOrg"
    NAME_GLOBALIZE_CREATE_POLICIES = "GlobalizeCreatePolicies"
    NAME_GLOBALIZE_CREATE_UPDATE_POLICY_SCOPE = "GlobalizeCreateUpdatePolicyScope"
    NAME_GLOBALIZE_CREATE_VLAN_ORG_PERMISSION = "GlobalizeCreateVlanOrgPermission"
    NAME_GLOBALIZE_FAIL = "GlobalizeFail"
    NAME_GLOBALIZE_REAPPLY_GSP = "GlobalizeReapplyGSP"
    NAME_GLOBALIZE_RESOLVE_GLOBAL_POOL_DN = "GlobalizeResolveGlobalPoolDn"
    NAME_GLOBALIZE_SUCCESS = "GlobalizeSuccess"
    NAME_GLOBALIZE_UNASSIGN_IDS = "GlobalizeUnassignIds"
    NAME_GLOBALIZE_UPDATE_DOMAIN_MOS = "GlobalizeUpdateDomainMos"
    NAME_NOP = "nop"
    STAGE_STATUS_FAIL = "fail"
    STAGE_STATUS_IN_PROGRESS = "inProgress"
    STAGE_STATUS_NOP = "nop"
    STAGE_STATUS_PENDING = "pending"
    STAGE_STATUS_SKIP = "skip"
    STAGE_STATUS_SUCCESS = "success"
    STAGE_STATUS_THROTTLED = "throttled"


class GlRequestFsmStage(ManagedObject):
    """This is GlRequestFsmStage class."""

    consts = GlRequestFsmStageConsts()
    naming_props = set(['name'])

    mo_meta = MoMeta("GlRequestFsmStage", "glRequestFsmStage", "stage-[name]", VersionMeta.Version201b, "OutputOnly", 0xf, [], [""], ['glRequestFsm'], [], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version201b, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "descr": MoPropertyMeta("descr", "descr", "string", VersionMeta.Version201b, MoPropertyMeta.READ_ONLY, None, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version201b, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "last_update_time": MoPropertyMeta("last_update_time", "lastUpdateTime", "string", VersionMeta.Version201b, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [""], []), 
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version201b, MoPropertyMeta.NAMING, None, None, None, None, ["CreateGlobalIdPoolBegin", "CreateGlobalIdPoolCreatePolicies", "CreateGlobalIdPoolFail", "CreateGlobalIdPoolSuccess", "CreateGlobalPolicyBegin", "CreateGlobalPolicyCreatePolicies", "CreateGlobalPolicyFail", "CreateGlobalPolicySuccess", "EvaluateBegin", "EvaluateEvaluate", "EvaluateFail", "EvaluateFetchDomainData", "EvaluateSuccess", "EvaluateValidate", "GlobalizeAddIdToGlobalPool", "GlobalizeAssignIds", "GlobalizeBegin", "GlobalizeCreateGSP", "GlobalizeCreateOrg", "GlobalizeCreatePolicies", "GlobalizeCreateUpdatePolicyScope", "GlobalizeCreateVlanOrgPermission", "GlobalizeFail", "GlobalizeReapplyGSP", "GlobalizeResolveGlobalPoolDn", "GlobalizeSuccess", "GlobalizeUnassignIds", "GlobalizeUpdateDomainMos", "nop"], []), 
        "order": MoPropertyMeta("order", "order", "ushort", VersionMeta.Version201b, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "retry": MoPropertyMeta("retry", "retry", "byte", VersionMeta.Version201b, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version201b, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "stage_status": MoPropertyMeta("stage_status", "stageStatus", "string", VersionMeta.Version201b, MoPropertyMeta.READ_ONLY, None, None, None, None, ["fail", "inProgress", "nop", "pending", "skip", "success", "throttled"], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version201b, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "descr": "descr", 
        "dn": "dn", 
        "lastUpdateTime": "last_update_time", 
        "name": "name", 
        "order": "order", 
        "retry": "retry", 
        "rn": "rn", 
        "stageStatus": "stage_status", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, name, **kwargs):
        self._dirty_mask = 0
        self.name = name
        self.child_action = None
        self.descr = None
        self.last_update_time = None
        self.order = None
        self.retry = None
        self.stage_status = None
        self.status = None

        ManagedObject.__init__(self, "GlRequestFsmStage", parent_mo_or_dn, **kwargs)




"""This module contains the general information for EquipmentSiocTempStats ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class EquipmentSiocTempStatsConsts():
    CMC_TEMP_NOT_APPLICABLE = "not-applicable"
    CMC_TEMP_AVG_NOT_APPLICABLE = "not-applicable"
    CMC_TEMP_MAX_NOT_APPLICABLE = "not-applicable"
    CMC_TEMP_MIN_NOT_APPLICABLE = "not-applicable"
    FRONT_TEMP_NOT_APPLICABLE = "not-applicable"
    FRONT_TEMP_AVG_NOT_APPLICABLE = "not-applicable"
    FRONT_TEMP_MAX_NOT_APPLICABLE = "not-applicable"
    FRONT_TEMP_MIN_NOT_APPLICABLE = "not-applicable"
    MID_TEMP_NOT_APPLICABLE = "not-applicable"
    MID_TEMP_AVG_NOT_APPLICABLE = "not-applicable"
    MID_TEMP_MAX_NOT_APPLICABLE = "not-applicable"
    MID_TEMP_MIN_NOT_APPLICABLE = "not-applicable"
    REAR_TEMP_NOT_APPLICABLE = "not-applicable"
    REAR_TEMP_AVG_NOT_APPLICABLE = "not-applicable"
    REAR_TEMP_MAX_NOT_APPLICABLE = "not-applicable"
    REAR_TEMP_MIN_NOT_APPLICABLE = "not-applicable"
    SUSPECT_FALSE = "false"
    SUSPECT_NO = "no"
    SUSPECT_TRUE = "true"
    SUSPECT_YES = "yes"
    VIC_TEMP_NOT_APPLICABLE = "not-applicable"
    VIC_TEMP_AVG_NOT_APPLICABLE = "not-applicable"
    VIC_TEMP_MAX_NOT_APPLICABLE = "not-applicable"
    VIC_TEMP_MIN_NOT_APPLICABLE = "not-applicable"


class EquipmentSiocTempStats(ManagedObject):
    """This is EquipmentSiocTempStats class."""

    consts = EquipmentSiocTempStatsConsts()
    naming_props = set([])

    mo_meta = MoMeta("EquipmentSiocTempStats", "equipmentSiocTempStats", "temp-stats", VersionMeta.Version151a, "OutputOnly", 0xf, [], ["admin", "operations", "read-only"], [], ['equipmentSiocTempStatsHist'], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version151a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "cmc_temp": MoPropertyMeta("cmc_temp", "cmcTemp", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "cmc_temp_avg": MoPropertyMeta("cmc_temp_avg", "cmcTempAvg", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "cmc_temp_max": MoPropertyMeta("cmc_temp_max", "cmcTempMax", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "cmc_temp_min": MoPropertyMeta("cmc_temp_min", "cmcTempMin", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "front_temp": MoPropertyMeta("front_temp", "frontTemp", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "front_temp_avg": MoPropertyMeta("front_temp_avg", "frontTempAvg", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "front_temp_max": MoPropertyMeta("front_temp_max", "frontTempMax", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "front_temp_min": MoPropertyMeta("front_temp_min", "frontTempMin", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "intervals": MoPropertyMeta("intervals", "intervals", "uint", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "mid_temp": MoPropertyMeta("mid_temp", "midTemp", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "mid_temp_avg": MoPropertyMeta("mid_temp_avg", "midTempAvg", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "mid_temp_max": MoPropertyMeta("mid_temp_max", "midTempMax", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "mid_temp_min": MoPropertyMeta("mid_temp_min", "midTempMin", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "normalized_time_col": MoPropertyMeta("normalized_time_col", "normalizedTimeCol", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []), 
        "rear_temp": MoPropertyMeta("rear_temp", "rearTemp", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "rear_temp_avg": MoPropertyMeta("rear_temp_avg", "rearTempAvg", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "rear_temp_max": MoPropertyMeta("rear_temp_max", "rearTempMax", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "rear_temp_min": MoPropertyMeta("rear_temp_min", "rearTempMin", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "stats_reported": MoPropertyMeta("stats_reported", "statsReported", "int", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "suspect": MoPropertyMeta("suspect", "suspect", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []), 
        "thresholded": MoPropertyMeta("thresholded", "thresholded", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "time_collected": MoPropertyMeta("time_collected", "timeCollected", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []), 
        "update": MoPropertyMeta("update", "update", "uint", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "vic_temp": MoPropertyMeta("vic_temp", "vicTemp", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "vic_temp_avg": MoPropertyMeta("vic_temp_avg", "vicTempAvg", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "vic_temp_max": MoPropertyMeta("vic_temp_max", "vicTempMax", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
        "vic_temp_min": MoPropertyMeta("vic_temp_min", "vicTempMin", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["not-applicable"], ["0-4294967295"]), 
    }

    prop_map = {
        "childAction": "child_action", 
        "cmcTemp": "cmc_temp", 
        "cmcTempAvg": "cmc_temp_avg", 
        "cmcTempMax": "cmc_temp_max", 
        "cmcTempMin": "cmc_temp_min", 
        "dn": "dn", 
        "frontTemp": "front_temp", 
        "frontTempAvg": "front_temp_avg", 
        "frontTempMax": "front_temp_max", 
        "frontTempMin": "front_temp_min", 
        "intervals": "intervals", 
        "midTemp": "mid_temp", 
        "midTempAvg": "mid_temp_avg", 
        "midTempMax": "mid_temp_max", 
        "midTempMin": "mid_temp_min", 
        "normalizedTimeCol": "normalized_time_col", 
        "rearTemp": "rear_temp", 
        "rearTempAvg": "rear_temp_avg", 
        "rearTempMax": "rear_temp_max", 
        "rearTempMin": "rear_temp_min", 
        "rn": "rn", 
        "statsReported": "stats_reported", 
        "status": "status", 
        "suspect": "suspect", 
        "thresholded": "thresholded", 
        "timeCollected": "time_collected", 
        "update": "update", 
        "vicTemp": "vic_temp", 
        "vicTempAvg": "vic_temp_avg", 
        "vicTempMax": "vic_temp_max", 
        "vicTempMin": "vic_temp_min", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.cmc_temp = None
        self.cmc_temp_avg = None
        self.cmc_temp_max = None
        self.cmc_temp_min = None
        self.front_temp = None
        self.front_temp_avg = None
        self.front_temp_max = None
        self.front_temp_min = None
        self.intervals = None
        self.mid_temp = None
        self.mid_temp_avg = None
        self.mid_temp_max = None
        self.mid_temp_min = None
        self.normalized_time_col = None
        self.rear_temp = None
        self.rear_temp_avg = None
        self.rear_temp_max = None
        self.rear_temp_min = None
        self.stats_reported = None
        self.status = None
        self.suspect = None
        self.thresholded = None
        self.time_collected = None
        self.update = None
        self.vic_temp = None
        self.vic_temp_avg = None
        self.vic_temp_max = None
        self.vic_temp_min = None

        ManagedObject.__init__(self, "EquipmentSiocTempStats", parent_mo_or_dn, **kwargs)




"""This module contains the general information for EquipmentPcieNode ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class EquipmentPcieNodeConsts():
    CHASSIS_ID_N_A = "N/A"
    OPER_STATE_ACCESSIBILITY_PROBLEM = "accessibility-problem"
    OPER_STATE_AUTO_UPGRADE = "auto-upgrade"
    OPER_STATE_BACKPLANE_PORT_PROBLEM = "backplane-port-problem"
    OPER_STATE_BIOS_POST_TIMEOUT = "bios-post-timeout"
    OPER_STATE_CHASSIS_LIMIT_EXCEEDED = "chassis-limit-exceeded"
    OPER_STATE_CONFIG = "config"
    OPER_STATE_DECOMISSIONING = "decomissioning"
    OPER_STATE_DEGRADED = "degraded"
    OPER_STATE_DISABLED = "disabled"
    OPER_STATE_DISCOVERY = "discovery"
    OPER_STATE_DISCOVERY_FAILED = "discovery-failed"
    OPER_STATE_EQUIPMENT_PROBLEM = "equipment-problem"
    OPER_STATE_FABRIC_CONN_PROBLEM = "fabric-conn-problem"
    OPER_STATE_FABRIC_UNSUPPORTED_CONN = "fabric-unsupported-conn"
    OPER_STATE_IDENTIFY = "identify"
    OPER_STATE_IDENTITY_UNESTABLISHABLE = "identity-unestablishable"
    OPER_STATE_INOPERABLE = "inoperable"
    OPER_STATE_MALFORMED_FRU = "malformed-fru"
    OPER_STATE_NOT_SUPPORTED = "not-supported"
    OPER_STATE_OPERABLE = "operable"
    OPER_STATE_PEER_COMM_PROBLEM = "peer-comm-problem"
    OPER_STATE_PERFORMANCE_PROBLEM = "performance-problem"
    OPER_STATE_POST_FAILURE = "post-failure"
    OPER_STATE_POWER_PROBLEM = "power-problem"
    OPER_STATE_POWERED_OFF = "powered-off"
    OPER_STATE_REMOVED = "removed"
    OPER_STATE_THERMAL_PROBLEM = "thermal-problem"
    OPER_STATE_UNKNOWN = "unknown"
    OPER_STATE_UPGRADE_PROBLEM = "upgrade-problem"
    OPER_STATE_VOLTAGE_PROBLEM = "voltage-problem"
    PRESENCE_EMPTY = "empty"
    PRESENCE_EQUIPPED = "equipped"
    PRESENCE_EQUIPPED_IDENTITY_UNESTABLISHABLE = "equipped-identity-unestablishable"
    PRESENCE_EQUIPPED_NOT_PRIMARY = "equipped-not-primary"
    PRESENCE_EQUIPPED_SLAVE = "equipped-slave"
    PRESENCE_EQUIPPED_UNSUPPORTED = "equipped-unsupported"
    PRESENCE_EQUIPPED_WITH_MALFORMED_FRU = "equipped-with-malformed-fru"
    PRESENCE_INACCESSIBLE = "inaccessible"
    PRESENCE_MISMATCH = "mismatch"
    PRESENCE_MISMATCH_IDENTITY_UNESTABLISHABLE = "mismatch-identity-unestablishable"
    PRESENCE_MISMATCH_SLAVE = "mismatch-slave"
    PRESENCE_MISSING = "missing"
    PRESENCE_MISSING_SLAVE = "missing-slave"
    PRESENCE_UNAUTHORIZED = "unauthorized"
    PRESENCE_UNKNOWN = "unknown"


class EquipmentPcieNode(ManagedObject):
    """This is EquipmentPcieNode class."""

    consts = EquipmentPcieNodeConsts()
    naming_props = set(['slotId'])

    mo_meta = MoMeta("EquipmentPcieNode", "equipmentPcieNode", "pcie-node-[slot_id]", VersionMeta.Version201v, "InputOutput", 0x1f, [], ["read-only"], ['computeBlade', 'equipmentChassis'], [], [None])

    prop_meta = {
        "chassis_id": MoPropertyMeta("chassis_id", "chassisId", "string", VersionMeta.Version201v, MoPropertyMeta.READ_ONLY, None, None, None, None, ["N/A"], ["0-255"]), 
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version201v, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version201v, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "fault_value": MoPropertyMeta("fault_value", "faultValue", "string", VersionMeta.Version201v, MoPropertyMeta.READ_ONLY, None, None, None, r"""((defaultValue|no-error|riser1absent-cpu1present|riser-mismatch|riser2present-cpu2absent|pcie-link-configissue|unknown-pcienode-present-on-riser2|unsupported-pcienode-present|powerfault|pcienode-present-xfm1-absent|unsupported-pcienode-present-on-riser1|riser1-powerfault|retimer-version-mismatch|unsupported-pcienode-present-on-riser2|riser2-powerfault|unknown-pcienode-present-on-riser1|unknown-pcienode-present),){0,16}(defaultValue|no-error|riser1absent-cpu1present|riser-mismatch|riser2present-cpu2absent|pcie-link-configissue|unknown-pcienode-present-on-riser2|unsupported-pcienode-present|powerfault|pcienode-present-xfm1-absent|unsupported-pcienode-present-on-riser1|riser1-powerfault|retimer-version-mismatch|unsupported-pcienode-present-on-riser2|riser2-powerfault|unknown-pcienode-present-on-riser1|unknown-pcienode-present){0,1}""", [], []), 
        "flt_aggr": MoPropertyMeta("flt_aggr", "fltAggr", "ulong", VersionMeta.Version201v, MoPropertyMeta.INTERNAL, None, None, None, None, [], []), 
        "model": MoPropertyMeta("model", "model", "string", VersionMeta.Version201v, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "oper_qualifier_reason": MoPropertyMeta("oper_qualifier_reason", "operQualifierReason", "string", VersionMeta.Version201v, MoPropertyMeta.READ_ONLY, None, None, None, r"""[ !#$%&\(\)\*\+,\-\./:;\?@\[\]_\{\|\}~a-zA-Z0-9]{0,256}""", [], []), 
        "oper_state": MoPropertyMeta("oper_state", "operState", "string", VersionMeta.Version201v, MoPropertyMeta.READ_ONLY, None, None, None, None, ["accessibility-problem", "auto-upgrade", "backplane-port-problem", "bios-post-timeout", "chassis-limit-exceeded", "config", "decomissioning", "degraded", "disabled", "discovery", "discovery-failed", "equipment-problem", "fabric-conn-problem", "fabric-unsupported-conn", "identify", "identity-unestablishable", "inoperable", "malformed-fru", "not-supported", "operable", "peer-comm-problem", "performance-problem", "post-failure", "power-problem", "powered-off", "removed", "thermal-problem", "unknown", "upgrade-problem", "voltage-problem"], []), 
        "peer_dn": MoPropertyMeta("peer_dn", "peerDn", "string", VersionMeta.Version201v, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "presence": MoPropertyMeta("presence", "presence", "string", VersionMeta.Version201v, MoPropertyMeta.READ_ONLY, None, None, None, None, ["empty", "equipped", "equipped-identity-unestablishable", "equipped-not-primary", "equipped-slave", "equipped-unsupported", "equipped-with-malformed-fru", "inaccessible", "mismatch", "mismatch-identity-unestablishable", "mismatch-slave", "missing", "missing-slave", "unauthorized", "unknown"], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version201v, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "serial_number": MoPropertyMeta("serial_number", "serialNumber", "string", VersionMeta.Version201v, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "slot_id": MoPropertyMeta("slot_id", "slotId", "uint", VersionMeta.Version201v, MoPropertyMeta.NAMING, 0x8, None, None, None, [], ["1-8"]), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version201v, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version201v, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "vendor": MoPropertyMeta("vendor", "vendor", "string", VersionMeta.Version201v, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
    }

    prop_map = {
        "chassisId": "chassis_id", 
        "childAction": "child_action", 
        "dn": "dn", 
        "faultValue": "fault_value", 
        "fltAggr": "flt_aggr", 
        "model": "model", 
        "operQualifierReason": "oper_qualifier_reason", 
        "operState": "oper_state", 
        "peerDn": "peer_dn", 
        "presence": "presence", 
        "rn": "rn", 
        "serialNumber": "serial_number", 
        "slotId": "slot_id", 
        "status": "status", 
        "type": "type", 
        "vendor": "vendor", 
    }

    def __init__(self, parent_mo_or_dn, slot_id, **kwargs):
        self._dirty_mask = 0
        self.slot_id = slot_id
        self.chassis_id = None
        self.child_action = None
        self.fault_value = None
        self.flt_aggr = None
        self.model = None
        self.oper_qualifier_reason = None
        self.oper_state = None
        self.peer_dn = None
        self.presence = None
        self.serial_number = None
        self.status = None
        self.type = None
        self.vendor = None

        ManagedObject.__init__(self, "EquipmentPcieNode", parent_mo_or_dn, **kwargs)




"""This module contains the general information for LsIdentityInfo ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class LsIdentityInfoConsts():
    UUID_IDENTITY_STATE_CONSISTENT = "consistent"
    UUID_IDENTITY_STATE_MISMATCH = "mismatch"
    WRITE_MODE_SYNC = "sync"
    WRITE_MODE_UNSYNC = "unsync"


class LsIdentityInfo(ManagedObject):
    """This is LsIdentityInfo class."""

    consts = LsIdentityInfoConsts()
    naming_props = set([])

    mo_meta = MoMeta("LsIdentityInfo", "lsIdentityInfo", "ls-identity-info", VersionMeta.Version151a, "InputOutput", 0x1f, [], ["admin", "ls-config", "ls-server"], ['computeBlade', 'computeRackUnit', 'computeServerUnit', 'lsServer'], ['faultInst'], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version151a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "uuid_identity_state": MoPropertyMeta("uuid_identity_state", "uuidIdentityState", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["consistent", "mismatch"], []), 
        "write_mode": MoPropertyMeta("write_mode", "writeMode", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x10, None, None, None, ["sync", "unsync"], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "rn": "rn", 
        "status": "status", 
        "uuidIdentityState": "uuid_identity_state", 
        "writeMode": "write_mode", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.status = None
        self.uuid_identity_state = None
        self.write_mode = None

        ManagedObject.__init__(self, "LsIdentityInfo", parent_mo_or_dn, **kwargs)




"""This module contains the meta information of ConfigGetNetRefs ExternalMethod."""

from ..ucsccoremeta import MethodMeta, MethodPropertyMeta

method_meta = MethodMeta("ConfigGetNetRefs", "configGetNetRefs", "Version142b")

prop_meta = {
    "cookie": MethodPropertyMeta("Cookie", "cookie", "Xs:string", "Version142b", "InputOutput", False),
    "in_org_dn": MethodPropertyMeta("InOrgDn", "inOrgDn", "ReferenceObject", "Version142b", "Input", False),
    "in_server_dn": MethodPropertyMeta("InServerDn", "inServerDn", "ReferenceObject", "Version142b", "Input", False),
    "in_type": MethodPropertyMeta("InType", "inType", "Xs:string", "Version142b", "Input", False),
    "out_configs": MethodPropertyMeta("OutConfigs", "outConfigs", "ConfigSet", "Version142b", "Output", True),
}

prop_map = {
    "cookie": "cookie",
    "inOrgDn": "in_org_dn",
    "inServerDn": "in_server_dn",
    "inType": "in_type",
    "outConfigs": "out_configs",
}

